@@ -6,10 +6,11 @@ from html.entities import name2codepoint
 from html import unescape
 from jinja2 import Template
 import asyncio
-from .tailwind import Tailwind
+from jpcore.tailwind import Tailwind
 import logging
 import httpx
 from jpcore.template import PageOptions
+from jpcore.component import Component
 from jpcore.webpage import WebPage as BaseWebPage
 
 # Dictionary for translating from tag to class
@@ -29,8 +30,6 @@ class JustPy:
     loop = None
     LOGGING_LEVEL = logging.DEBUG
     component_registry = {}
-    # Meadows
-    meadows = False
     
 class WebPage(BaseWebPage):
     """
@@ -87,39 +86,18 @@ class TailwindUIPage(WebPage):
         super().__init__(**kwargs)
         self.template_file = "tailwindui.html"
 
-class MeadowsPage(WebPage):
-    # https://tailwindui.com/components
-
-    def __init__(self, **kwargs):
-        super().__init__(**kwargs)
-        self.meadows = True
-        self.meadows_data = {
-            "if": [],
-            "show": [],
-            "attrs": [],
-            "for": [],
-            "class": [],
-            "class_evaluate": [],
-            "refs": Dict({}),
-            "event_handler_count": 0,
-            "events": Dict({}),
-        }
-
-    async def on_disconnect(self, websocket=None):
-        if self.delete_flag:
-            self.delete_components()
-            del self.meadows_data
-            self.remove_page()
-
-
-class JustpyBaseComponent(Tailwind):
-    next_id = 1
-    instances = {}
+class JustpyBaseComponent(Component):
+    """
+    the base class for all Justpy components
+    """
     temp_flag = True
     delete_flag = True
     needs_deletion = False
 
     def __init__(self, **kwargs):
+        """
+        constructor
+        """
         cls = JustpyBaseComponent
         temp = kwargs.get("temp", cls.temp_flag)
         delete_flag = kwargs.get("delete_flag", cls.delete_flag)
@@ -172,9 +150,8 @@ class JustpyBaseComponent(Tailwind):
         debounce=None,
         throttle=None,
         immediate=False,
-        meadows=False,
     ):
-        if meadows or event_type in self.allowed_events:
+        if event_type in self.allowed_events:
             cls = JustpyBaseComponent
             if not self.id:
                 self.id = cls.next_id
