@@ -12,7 +12,7 @@ from .chartcomponents import *
 from .gridcomponents import *
 from .quasarcomponents import *
 
-from jpcore.justpy_app import cookie_signer, template_options, handle_event, JustpyApp,JustpyEndpoint
+from jpcore.justpy_app import cookie_signer, template_options, handle_event, JustpyApp,JustpyAjaxEndpoint
 from jpcore.justpy_config import config, AGGRID, AGGRID_ENTERPRISE,BOKEH,COOKIE_MAX_AGE, CRASH
 from jpcore.justpy_config import DEBUG,DECKGL, FAVICON, HIGHCHARTS,HOST,KATEX, LATENCY,LOGGING_LEVEL
 from jpcore.justpy_config import MEMORY_DEBUG, NO_INTERNET, PLOTLY, PORT, SECRET_KEY, SESSION_COOKIE_NAME, SESSIONS
@@ -21,10 +21,10 @@ from jpcore.justpy_config import QUASAR, QUASAR_VERSION,TAILWIND, UVICORN_LOGGIN
 JustPy.LOGGING_LEVEL = LOGGING_LEVEL
 # from .misccomponents import *
 from .pandas import *
-from .routing import Route, JpRoute, SetRoute
+from .routing import SetRoute
 from .utilities import run_task, create_delayed_task
 import uvicorn, logging, sys, os, traceback
-
+import typing
 #
 # globals
 #
@@ -89,15 +89,9 @@ async def justpy_startup():
     protocol = "https" if SSL_KEYFILE else "http"
     print(f"JustPy ready to go on {protocol}://{HOST}:{PORT}")
 
-
-@app.route("/")
-class Homepage(JustpyEndpoint):
-    """
-    Justpy main page handler
-    """
     
 @app.route("/zzz_justpy_ajax")
-class AjaxEndpoint(JustpyEndpoint):
+class AjaxEndpoint(JustpyAjaxEndpoint):
     """
     Justpy ajax handler
     """
@@ -196,6 +190,15 @@ def get_server():
     """
     return jp_server
 
+def Route(path:str,wpfunc:typing.Callable):
+    """
+    legacy Route handling
+    
+    Args:
+        path:str
+    """
+    app.add_jproute(path,wpfunc)
+
 
 def justpy(
     func=None,
@@ -237,7 +240,7 @@ def justpy(
         WebPage.use_websockets = True
     else:
         WebPage.use_websockets = False
-    JpRoute("/", func_to_run, name="default")
+    app.add_jproute("/", func_to_run)
     for k, v in kwargs.items():
         template_options[k.lower()] = v
 
